@@ -13,7 +13,7 @@ class GuardianClient:
         else:
             self.token_endpoint = f"{base_url}/maskinporten/access-token"
 
-    @exception_handler("Guardian Client")
+    @exception_handler("Guardian Client", retries=3)
     def get_token(self, keycloak_token: str) -> str:
         headers = {
             "Authorization": f"Bearer {keycloak_token}",
