@@ -18,4 +18,12 @@ class UtsendingFormat(str, Enum):
     pdf = "PDF"
     text = "TXT"
     html = "HTML"
+    json = "JSON"
+    md = "MD"
     xml = "XML"
+
+
+class UtsendingsKanal(str, Enum):
+    altinn = "altinn"
+    epost = "epost"
+    sms = "sms"
