@@ -1,12 +1,12 @@
 import os
 from pydantic import BaseModel, model_validator, field_validator
-from typing import Optional
+from typing import Optional, Any
 
 
 # https://docs.pydantic.dev/latest/migration/#required-optional-and-nullable-fields
 class Altinn3CloudEvent(BaseModel):
     alternativesubject: Optional[str] = None
-    data: Optional[str] = None
+    data: Optional[Any] = None
     datacontenttype: Optional[str] = None
     id: str
     source: str
@@ -14,6 +14,8 @@ class Altinn3CloudEvent(BaseModel):
     subject: Optional[str] = None
     time: Optional[str] = None
     type: str
+    resource: Optional[str] = None
+    resourceinstance: Optional[str] = None
 
     @field_validator("source")
     def validate_event_source(cls, v: str) -> str:
